function [line, sta] = lat2cc(la,lo) 
% DESCRIPTION: Use this function to convert from degree decimal lat 
% and long to calcofi grid coordinates. This uses the CalCOFI de-gridding 
% algorithm (Eber and Hewitt 1979).  This is the inverse of the function 
% cc2lat.  It is more complicated because this one requires
% some non-algebraic iteration.
% 
% INPUT: latitude and longitude values in decimal degrees to be converted
% OUTPUT: This function outputs a line and station value 
% ASSUMPTIONS: All lat/long and station values are from the Northwestern
%               hemisphere and within the middle latitudes.
% REFERENCE: Eber and Hewitt 1979, Conversion Algorithms for the CalCOFI 
%            Station Grid
% WRITTEN BY: Robert Thombley (2006), Scripps Institution of Oceanography,
% CalCOFI
% MODIFIED BY: Augusto Valencia (2014), Universidad de Baja California-UABC,
% based on Weber & Moore 2013.

if lo<=180
    lo=-lo;
else
    lo=lo-360;
end
l1 = (mctr(la) - mctr(34.15))*tan(cRad(30));
l2 = lo - l1 - 121.15;
mrla = l2*cos(cRad(30))*sin(cRad(30)) + mctr(la);
rla = invmctr(mrla);
line = 80 - (rla - 34.15)*5/cos(cRad(30));
sta = 60 + (rla - la)*15/sin(cRad(30));


function rad = cRad(deg)
% DESCRIPTION: A simple helper function that converts degrees to radians
% INPUT: angle in degrees
% OUPUT: angle in radians
% WRITTEN BY: Robert Thombley SIO 2006
	rad = deg * pi/180;

function val = invmctr(f1)
% DESCRIPTION: Inverse mercator transform.  Because this function does not 
% have a precise algebraic form, an iterative process is employed.
% INPUT: A value in mercator units
% OUTPUT: value in decimal degrees
% WRITTEN BY: Robert Thombley SIO 2006
    t2 = f1*pi/180;
    for i=1:5
		f1 = 2*(atan(exp(t2 + 0.00676866*sin(cRad(f1))))*180/pi - 45);
    end
    val = f1;

function val = mctr(t1)
% DESCRIPTION: Mercator transform function.  
% INPUT: Latitude value in decimal degrees
% OUTPUT: value in mercator units
% WRITTEN BY: Robert Thombley SIO 2006

	val = 180/pi* (log(tan(cRad(45 + t1/2))) - 0.00676866 * sin(cRad(t1)));